import { HazelReader, HazelWriter } from "@skeldjs/util";
import { SystemType } from "@skeldjs/constant";
import { RepairSystemMessage } from "@skeldjs/protocol";
import { ExtractEventTypes } from "@skeldjs/events";
import { InnerShipStatus } from "../objects";
import { SystemStatus } from "./SystemStatus";
import { PlayerData } from "../PlayerData";
import { HeliSabotageConsoleOpenEvent, HeliSabotageConsolesResetEvent, HeliSabotageConsoleCloseEvent, HeliSabotageConsoleCompleteEvent } from "../events";
import { SystemStatusEvents } from "./events";
import { Hostable } from "../Hostable";
export interface HeliSabotageSystemData {
    countdown: number;
    resetTimer: number;
    activeConsoles: Map<number, number>;
    completedConsoles: Set<number>;
}
export declare type HeliSabotageSystemEvents<RoomType extends Hostable = Hostable> = SystemStatusEvents<RoomType> & ExtractEventTypes<[
    HeliSabotageConsoleOpenEvent,
    HeliSabotageConsolesResetEvent,
    HeliSabotageConsoleCloseEvent,
    HeliSabotageConsoleCompleteEvent
]>;
export declare const HeliSabotageSystemRepairTag: {
    readonly FixBit: 16;
    readonly DeactiveBit: 32;
    readonly ActiveBit: 64;
    readonly DamageBit: 128;
};
/**
 * Represents a system responsible for handling communication sabotages on The Skeld and Polus.
 *
 * See {@link HeliSabotageSystemEvents} for events to listen to.
 */
export declare class HeliSabotageSystem<RoomType extends Hostable = Hostable> extends SystemStatus<HeliSabotageSystemData, HeliSabotageSystemEvents, RoomType> implements HeliSabotageSystemData {
    private _syncTimer;
    countdown: number;
    resetTimer: number;
    activeConsoles: Map<number, number>;
    completedConsoles: Set<number>;
    /**
     * Whether or not communications is sabotaged.
     */
    get sabotaged(): boolean;
    constructor(ship: InnerShipStatus<RoomType>, systemType: SystemType, data?: HazelReader | HeliSabotageSystemData);
    patch(data: HeliSabotageSystemData): void;
    Deserialize(reader: HazelReader, spawn: boolean): void;
    Serialize(writer: HazelWriter, spawn: boolean): void;
    HandleSabotage(player: PlayerData | undefined, rpc: RepairSystemMessage | undefined): Promise<void>;
    private _resetConsoles;
    private _openConsole;
    openConsoleAs(consoleId: number, player: PlayerData): Promise<void>;
    /**
     * Mark the console as being used by your player.
     * @param consoleId The ID of the console to mark as being used.
     */
    openConsole(consoleId: number): Promise<void>;
    private _closeConsole;
    closeConsoleAs(consoleId: number, player: PlayerData): Promise<void>;
    /**
     * Mark the console as no longer being used by your player.
     * @param consoleId The ID of the console to mark as not being used.
     */
    closeConsole(consoleId: number): Promise<void>;
    private _completeConsole;
    /**
     * Mark a console as completed.
     * @param consoleId The ID of the console to mark as completed.
     */
    completeConsole(consoleId: number): Promise<void>;
    _repair(player: PlayerData | undefined, rpc: RepairSystemMessage | undefined): Promise<void>;
    repair(): Promise<void>;
    HandleRepair(player: PlayerData<RoomType> | undefined, amount: number, rpc: RepairSystemMessage | undefined): Promise<void>;
    Detoriorate(delta: number): void;
}
//# sourceMappingURL=HeliSabotageSystem.d.ts.map